import 'package:flutter/material.dart';
import 'package:navigine_api/navigine_api.dart';
import '../widgets/sub_location_image.dart';

class SubLocationDetail extends StatefulWidget {
  final SubLocation subLocation;
  SubLocationDetail({this.subLocation});

  @override
  _SubLocationDetailState createState() => _SubLocationDetailState();
}

class _SubLocationDetailState extends State<SubLocationDetail> {
  SubLocation subLocation;

  initState() {
    super.initState();
    subLocation = widget.subLocation;
  }

  addBeacon() async {
    await subLocation.addBeacon(
      uuid: "ffffffff-1234-aaaa-1a2b-a1b2c3d4e5f6",
      description: "Test Beacon",
      kx: .5,
      ky: .5,
      major: 100,
      minor: 1,
      powerNav: 1,
      pw: 1,
      isUsed: 0,
    );
  }

  deleteBeacon(Beacon beacon) async {
    await subLocation.deleteBeacon(id: beacon.id);
    subLocation.beacons = await subLocation.getAllBeacons();
    setState(() {});
  }

  beaconOption(Beacon beacon) {
    showDialog(
      context: context,
      builder: (_) => SimpleDialog(
        children: <Widget>[
          ListTile(
            leading: Icon(Icons.delete),
            title: Text("Delete beacon"),
            onTap: () {
              Navigator.pop(context);
              deleteBeacon(beacon);
            },
          )
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(subLocation.title),
      ),
      floatingActionButton: FloatingActionButton.extended(
        label: Text("Add new beacon"),
        icon: Icon(Icons.add),
        onPressed: addBeacon,
      ),
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            SubLocationWidget(subLocation),
            for (Beacon beacon in subLocation.beacons)
              ListTile(
                title: Text(beacon.id.toString()),
                subtitle: Text(beacon.uuid),
                onTap: () => beaconOption(beacon),
                trailing: Text("(${beacon.kx}, ${beacon.ky})"),
              )
          ],
        ),
      ),
    );
  }
}
